FileHandler class

Properties

file Future<File>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkFilesExist({required List<String> filePaths, String assetPath = 'assets', FileExistenceFilter filter = FileExistenceFilter.both}) Future<List<String>>
Checks for existence of files in local storage
deleteData(String key) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readData(String key, ISerializable? serializableObject) Future<ISerializable?>
toString() String
A string representation of this object.
inherited
updateData({required String key, required ISerializable updatedData}) Future<void>
writeData({ISerializable? data, required String key}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

cachedLoadedData Map<String, String>
getter/setter pair
fileName String
getter/setter pair
instance FileHandler
final