LocalStorage class

Constructors

LocalStorage()
factory

Properties

database Future<Database>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteAllItems({required String tableName}) Future<int>
deleteItem({required String tableName, required String id}) Future<int>
deleteItemList({required String tableName, required List<String> ids}) Future<int>
deleteTable({required String tableName}) Future<void>
exists({required String tableName, required String id}) Future<bool>
getItem({required String tableName, String? fieldName = 'id', required String fieldValue}) Future<Map<String, dynamic>?>
getItems({required String tableName}) Future<List<Map<String, dynamic>>>
insertItem({required String tableName, required Map<String, dynamic> item, required String id, bool updateFallback = false}) Future<int>
insertItemList({required String tableName, required List<Map<String, dynamic>> items}) Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tableExists({required String tableName}) Future<bool>
toString() String
A string representation of this object.
inherited
updateItem({required String tableName, required String id, required Map<String, dynamic> item}) Future<int>

Operators

operator ==(Object other) bool
The equality operator.
inherited