Logger class

Constructors

Logger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom(Object? object, String color) → void
error(Object? object) → void
highlight(Object? object) → void
info(Object? object) → void
log(String message) → void
task(Object? object) → void
test(Object? object) → void
warn(Object? object) → void