AssetRegister class
Constructors
- AssetRegister()
-
factory
Properties
-
all
→ Map<
String, String> -
Returns all registered asset paths.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
names
→ List<
String> -
Returns all registered asset names.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<
String> -
Returns all registered asset paths as a list.
no setter
Methods
-
autoRegisterUsingAppAsset(
List< AppAsset> appAssets) → void -
clear(
) → void - Clears all registered assets.
-
getPath(
String name) → String? - Retrieves the path of a registered asset by its name.
-
isRegistered(
String path) → bool - Checks if an asset is registered.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
String name, String path) → void - Registers a single asset path.
-
registerAll(
Map< String, String> assets) → void - Registers multiple asset paths at once.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → AssetRegister
-
no setter