AssetRegister class

Constructors

AssetRegister()
factory

Properties

all List<String>
Returns all registered asset paths as a list.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clears all registered assets.
isRegistered(String path) bool
Checks if an asset is registered.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(String path) → void
Registers a single asset path.
registerAll(Iterable<String> paths) → void
Registers multiple asset paths at once.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance AssetRegister
no setter